import 'server-only';
import { createIntl } from 'use-intl/dist/src/core';
import NextRequestStorage from './NextRequestStorage';
class NextIntlRequestStorage {
    constructor() {
        this.key = '__next-intl';
        this.storage = new NextRequestStorage(this.key);
    }
    initRequest(opts) {
        const now = opts.now || new Date();
        // Since `useIntl` doesn't take any params, we can cache it here.
        const intl = createIntl(opts);
        this.storage.set({ ...opts, intl, now });
    }
    isInitialized() {
        return this.storage.get() != null;
    }
    getIntlOpts() {
        // eslint-disable-next-line @typescript-eslint/no-unused-vars
        const { intl, ...opts } = this.getInitializedStorage();
        return opts;
    }
    getLocale() {
        return this.getInitializedStorage().locale;
    }
    getIntl() {
        return this.getInitializedStorage().intl;
    }
    getNow() {
        return this.getInitializedStorage().now;
    }
    getTimeZone() {
        return this.getInitializedStorage().timeZone;
    }
    getInitializedStorage() {
        if (!this.isInitialized()) {
            throw new Error('`NextIntlServerProvider` was not initialized.');
        }
        return this.storage.get();
    }
}
// Provide a singleton-instance of the storage.
const instance = new NextIntlRequestStorage();
export default instance;
//# sourceMappingURL=NextIntlRequestStorage.js.map